> Currently, P-384 field operations use 14x28-bit limbs. The efficiency of 
> these operations vastly improve by using a 7x55-bit limb configuration.  
> Performance gains yield 32% to 43% for Java alone:
> 
> AArch64:
> Key pair generation - P-384: +41%
> Key agreement - P-384: +43%
> 
> Key pair generation - secP384r1MLKEM1024: +38%
> KEM  decapsulation - secP384r1MLKEM1024: +42%
> KEM encapsulation - secP384r1MLKEM1024: +42%
> 
> x86_64:
> Key pair generation - P-384: +35%
> Key agreement - P-384: +35%
> 
> Key pair generation - secP384r1MLKEM1024: +32%
> KEM  decapsulation - secP384r1MLKEM1024: +32%
> KEM encapsulation - secP384r1MLKEM1024: +33%
> 
> ---------
> - [X] I confirm that I make this contribution in accordance with the [OpenJDK 
> Interim AI Policy](https://openjdk.org/legal/ai).

Shawn Emery has updated the pull request incrementally with one additional 
commit since the last revision:

  Improve x86_64 performance by 13%

-------------

Changes:
  - all: https://git.openjdk.org/jdk/pull/33193/files
  - new: https://git.openjdk.org/jdk/pull/33193/files/94527c9d..68cd0824

Webrevs:
 - full: https://webrevs.openjdk.org/?repo=jdk&pr=33193&range=01
 - incr: https://webrevs.openjdk.org/?repo=jdk&pr=33193&range=00-01

  Stats: 253 lines in 1 file changed: 22 ins; 26 del; 205 mod
  Patch: https://git.openjdk.org/jdk/pull/33193.diff
  Fetch: git fetch https://git.openjdk.org/jdk.git pull/33193/head:pull/33193

PR: https://git.openjdk.org/jdk/pull/33193

Reply via email to